# Genetic Algorithm Utility for python

### What is Genetic Algorithm ?
Genetic Algorithm is inspired by the natural selection process in our environment. GA is very good for optimisation problems , read more about  [GA here](https://en.wikipedia.org/wiki/Genetic_algorithm) . 

### The ga2 module 
ga2 is a highly flexible and easy to use utility module implementing Genetic Algorithm. 

### Installation
* standard pip3 installation is supported
```
pip3 install ga2
```

* import the Genetic Algorithm utility as 
```
import ga2.gaDisc as gad

session1 = gad.Session()
print(session1.sessID)
```
this should print the session ID of that session

### Usage
ga2 is designed to be flexible and also simple to use for a variety of use cases, check the [EXAMPLES.md](EXAMPLES.md) for examples. Documentation will be done as soon as a stable stage is reached

### Current Development
gaDisc (Genetic Algorithm Discrete) is working and is in its first release stage, a lot of planning and designing needs to be done for gaCont (Genetic Algorithm continuous), which I hope will be soon !.
*  - [x] gaDisc
*  - [ ] gaCont

Open to ideas , and contributions ! 